/* -*- Mode: C; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */

/* Copyright (C) 2018-2024 Hans Petter Jansson
 *
 * This file is part of Chafa, a program that shows pictures on text terminals.
 *
 * Chafa is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Chafa is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Chafa.  If not, see <http://www.gnu.org/licenses/>. */

#ifndef __CHAFA_UTIL_H__
#define __CHAFA_UTIL_H__

#if !defined (__CHAFA_H_INSIDE__) && !defined (CHAFA_COMPILATION)
# error "Only <chafa.h> can be included directly."
#endif

G_BEGIN_DECLS

/* Miscellaneous functions */

CHAFA_AVAILABLE_IN_ALL
void chafa_calc_canvas_geometry (gint src_width,
                                 gint src_height,
                                 gint *dest_width_inout,
                                 gint *dest_height_inout,
                                 gfloat font_ratio,
                                 gboolean zoom,
                                 gboolean stretch);

CHAFA_AVAILABLE_IN_1_14
void chafa_free_gstring_array (GString **gsa);

G_END_DECLS

#endif /* __CHAFA_UTIL_H__ */
